==> datadog-api-client-1.10.0.tar.gz: datadog-api-client-1.10.0/src/datadog_api_client/v2/model/permission_attributes.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v2.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
)


class PermissionAttributes(ModelNormal):

    validations = {}

    @cached_property
    def openapi_types():
        return {
            "created": (datetime,),
            "description": (str,),
            "display_name": (str,),
            "display_type": (str,),
            "group_name": (str,),
            "name": (str,),
            "restricted": (bool,),
        }

    attribute_map = {
        "created": "created",
        "description": "description",
        "display_name": "display_name",
        "display_type": "display_type",
        "group_name": "group_name",
        "name": "name",
        "restricted": "restricted",
    }

    read_only_vars = {}

    def __init__(self, *args, **kwargs):
        """
        Attributes of a permission.

        :param created: Creation time of the permission.
        :type created: datetime, optional

        :param description: Description of the permission.
        :type description: str, optional

        :param display_name: Displayed name for the permission.
        :type display_name: str, optional

        :param display_type: Display type.
        :type display_type: str, optional

        :param group_name: Name of the permission group.
        :type group_name: str, optional

        :param name: Name of the permission.
        :type name: str, optional

        :param restricted: Whether or not the permission is restricted.
        :type restricted: bool, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(PermissionAttributes, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self

==> datadog-api-client-2.3.0.tar.gz: datadog-api-client-2.3.0/src/datadog_api_client/v2/model/permission_attributes.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
)


class PermissionAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "created": (datetime,),
            "description": (str,),
            "display_name": (str,),
            "display_type": (str,),
            "group_name": (str,),
            "name": (str,),
            "restricted": (bool,),
        }

    attribute_map = {
        "created": "created",
        "description": "description",
        "display_name": "display_name",
        "display_type": "display_type",
        "group_name": "group_name",
        "name": "name",
        "restricted": "restricted",
    }

    def __init__(self, *args, **kwargs):
        """
        Attributes of a permission.

        :param created: Creation time of the permission.
        :type created: datetime, optional

        :param description: Description of the permission.
        :type description: str, optional

        :param display_name: Displayed name for the permission.
        :type display_name: str, optional

        :param display_type: Display type.
        :type display_type: str, optional

        :param group_name: Name of the permission group.
        :type group_name: str, optional

        :param name: Name of the permission.
        :type name: str, optional

        :param restricted: Whether or not the permission is restricted.
        :type restricted: bool, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(PermissionAttributes, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
